aboutsummaryrefslogtreecommitdiffstats
path: root/lib/common_test/src/vts.erl
diff options
context:
space:
mode:
authorPeter Andersson <[email protected]>2015-04-03 21:52:16 +0200
committerPeter Andersson <[email protected]>2015-05-04 12:16:19 +0200
commitd54155d35919a4a7fee25dec05ae74e2b74104a9 (patch)
tree42b6cdade7186e109bb91ca4e77aa71822c12d47 /lib/common_test/src/vts.erl
parentff1e0b2fe44a347670a5d72c45c061fefa6abc7f (diff)
downloadotp-d54155d35919a4a7fee25dec05ae74e2b74104a9.tar.gz
otp-d54155d35919a4a7fee25dec05ae74e2b74104a9.tar.bz2
otp-d54155d35919a4a7fee25dec05ae74e2b74104a9.zip
Prepare for webtool integration with CT
OTP-12704
Diffstat (limited to 'lib/common_test/src/vts.erl')
-rw-r--r--lib/common_test/src/vts.erl10
1 files changed, 5 insertions, 5 deletions
diff --git a/lib/common_test/src/vts.erl b/lib/common_test/src/vts.erl
index b340c6fdd1..ab13e7d0ee 100644
--- a/lib/common_test/src/vts.erl
+++ b/lib/common_test/src/vts.erl
@@ -63,21 +63,21 @@
%%%-----------------------------------------------------------------
%%% User API
start() ->
- webtool:start(),
- webtool:start_tools([],"app=vts").
+ ct_webtool:start(),
+ ct_webtool:start_tools([],"app=vts").
init_data(ConfigFiles,EvHandlers,LogDir,LogOpts,Tests) ->
call({init_data,ConfigFiles,EvHandlers,LogDir,LogOpts,Tests}).
stop() ->
- webtool:stop_tools([],"app=vts"),
- webtool:stop().
+ ct_webtool:stop_tools([],"app=vts"),
+ ct_webtool:stop().
report(What,Data) ->
call({report,What,Data}).
%%%-----------------------------------------------------------------
%%% Return config data used by webtool
config_data() ->
{ok,LogDir} =
case lists:keysearch(logdir,1,init:get_arguments()) of
@@ -63,21 +63,21 @@
call({report,What,Data}).
%%%-----------------------------------------------------------------
-%%% Return config data used by webtool
+%%% Return config data used by ct_webtool
config_data() ->
{ok,LogDir} =